import { LaunchableHandlerType } from './types.js';
/**
 * Represents a ContainerExecution class that handles the execution of a launchable handler.
 * @template Input - The type of input expected by the launchable handler.
 */
export default class ContainerExecution<Input> {
    /**
     * A private readonly property that holds a handler of LaunchableHandlerType with a given Input type.
     */
    private readonly handler;
    /**
     * Constructor for creating an instance of a class with a LaunchableHandlerType input.
     * @param {LaunchableHandlerType<Input>} handler - The handler for the launchable type.
     * @returns None
     */
    constructor(handler: LaunchableHandlerType<Input>);
    /**
     * Executes the function asynchronously, invoking the specified inputs and handling the response accordingly.
     * If the response code is 200, the process exits with code 0; otherwise, it exits with code 1.
     * @returns None
     */
    execute(): Promise<void>;
    /**
     * Retrieves inputs from the process arguments and parses them as JSON.
     * @returns {any} The parsed input object from process arguments.
     */
    private getInputs;
    /**
     * Builds a context object for AWS Lambda function.
     * @param {CallableFunction} callback - The callback function to be executed.
     * @returns {Context} A context object with AWS Lambda properties.
     */
    private buildContext;
    /**
     * Asynchronously invokes a function with the given input and returns a promise that resolves
     * with an object containing an error message or data response.
     * @param {any} input - The input to be passed to the function.
     * @returns {Promise<{ err?: string; data?: any }>} A promise that resolves with an object
     * containing an error message or data response (serialized).
     */
    private invoke;
}
