import { LaunchableHandlerType } from './types.js';
/**
 * Represents a Launchable class that can be used to handle launchable items.
 * @template Input - The type of input expected by the LaunchableHandlerType.
 */
export default class Launchable<Input = any> {
    /**
     * A private readonly property that holds a handler for launching with a specific input type.
     * @type {LaunchableHandlerType<Input>}
     */
    private readonly handler;
    /**
     * Constructor for creating an instance of a class with a LaunchableHandlerType input.
     * @param {LaunchableHandlerType<Input>} handler - The handler for the launchable type.
     * @returns None
     */
    constructor(handler: LaunchableHandlerType<Input>);
    /**
     * Returns the export function based on whether the object is a container or not.
     * If it is a container, it returns the container export function, otherwise it returns the handler function.
     * @returns {CallableFunction} The export function to be used.
     */
    getExport(): CallableFunction;
    /**
     * Checks if the current element is a container by calling the isHybridlessContainer method from the Utils class.
     * @returns {boolean} - true if the element is a container, false otherwise.
     */
    private isContainer;
    /**
     * Returns a callable function that executes a ContainerExecution instance and returns a promise.
     * @returns {CallableFunction} A function that when called, executes a ContainerExecution instance.
     */
    private getContainerExport;
}
