import { Context } from 'aws-lambda'

import Response from '../../API/Response.js'

/**
 * Defines a type for a launchable handler that takes an input event and context,
 * and returns a promise of a response.
 * @param {Input} event - The input event for the handler.
 * @param {Context} context - The context for the handler.
 * @returns {Promise<Response<any>>} A promise that resolves to a response.
 */
export type LaunchableHandlerType<Input> = (
  event: Input,
  context: Context
) => Promise<Response<any> | null>
